<?php
/**
 * Display the meta data of the post*
 
 * @ Theme Manduca - focus on accessibility
 * @ Since  17.1
 **/


$categories_list = get_the_category_list( ', ' );
$tag_list = get_the_tag_list( '', ', ' );	
$date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><abbr class="published" title="%3$s"><time class="entry-date" datetime="%3$s">%4$s</time></abbr></a>',
	esc_url( get_permalink() ),
	esc_attr( get_the_time() ),
	esc_attr( get_the_date( 'c' ) ),
	esc_html( get_the_date() )
);


$author = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
	esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
	esc_attr( sprintf( __( 'All posts by %s', ' manduca' ), get_the_author() ) ),
	get_the_author()
);

$modified_date = sprintf( '<time class="updated" datetime="%1$s">%2$s</time></a>',
	esc_attr( get_the_modified_date( 'c' ) ),
	esc_html( get_the_modified_date( ) )
);


$utility_text ='<div>';
$utility_text .='<h2 class="screen-reader-text">'. __( 'Post meta', 'manduca' ) .'</h2>';
$utility_text .= "<ul>";

$utility_text .= '<li>' .manduca_get_svg( array( 'icon' => 'calendar' ) ) . ':<span> ' .__( 'Entry date', 'manduca' ) .':</span> ' . $date .'</li>';

if( get_the_date() !== get_the_modified_date() ) {
	$utility_text .='<li>' .manduca_get_svg( array( 'icon' => 'calendar-add' ) ) . ':<span> ' .'<span> ' . __( 'Last revision:', 'manduca' ) .':</span> ' .$modified_date .'</li>';
}

$utility_text .= '<li>' .manduca_get_svg( array( 'icon' => 'author' ) ) . ':<span> ' .__( 'Author', 'manduca' ) .':</span> ' . $author .'</li>';

if ( $categories_list ) {
	$utility_text .='<li>' .manduca_get_svg( array( 'icon' => 'folder-open' ) ) . ':<span> ' .__( 'Category', 'manduca' ) .':</span> ' .$categories_list .'</li>';
}

if ( $tag_list ) {
	$utility_text .= '<li>' .manduca_get_svg( array( 'icon' => 'tags' ) ) . ':<span> '. __( 'Tags', 'manduca' ) .':</span> ' .$tag_list .'</li>';
}


$utility_text .='</ul>' .PHP_EOL .'</div>';

$utility_text = apply_filters( 'manduca_post_meta', $utility_text );

echo $utility_text;
	


if ( is_singular() && get_the_author_meta( 'description' ) && is_multi_author() ) :  ?>
	<div class="author-info">
		<div class="author-avatar">
			<?php echo get_avatar( get_the_author_meta( 'user_email' ), 68 ); ?>
		</div>
		
		<div class="author-description">
			<h3><?php printf( __( 'Author: %s', 'manduca' ), get_the_author() ); ?></h3>
			<p><?php the_author_meta( 'description' ); ?></p>
			<div class="author-link">
				<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author">
					<?php printf( __( 'All posts by %s', 'manduca' ) . manduca_get_svg( array( 'icon' => 'icon-arrow-right' ) , get_the_author() ) ); ?>
				</a>
			</div>
		</div>
	</div>
<?php endif; ?>

